# ProrationOption

**Note**: This field is only available if you have the [Prepaid with Drawdown](https://knowledgecenter.zuora.com/Billing/Billing_and_Payments/J_Billing_Operations/Prepaid_with_Drawdown) feature enabled. To use this field, you must set the `X-Zuora-WSDL-Version` request header to 135 or higher. Otherwise, an error occurs. This field defines the proration options for a usage charge or recurring charge. 

## Enum

* `NOPRORATION` (value: `'NoProration'`)

* `TIMEBASEDPRORATION` (value: `'TimeBasedProration'`)

* `DEFAULTFROMTENANTSETTING` (value: `'DefaultFromTenantSetting'`)

* `CHARGEFULLPERIOD` (value: `'ChargeFullPeriod'`)

* `CUSTOMIZEPRORATIONOPTIONOVERRIDES` (value: `'CustomizeProrationOptionOverrides'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


